//
// HtCodec.cc
//
// HtCodec:  Provide a generic means to take a String, code
//           it, and return the encoded string.  And vice versa.
//
// Keep constructor and destructor in a file of its own.
//
// Part of the ht://Dig package   <http://www.htdig.org/>
// Copyright (c) 1999 The ht://Dig Group
// For copyright details, see the file COPYING in your distribution
// or the GNU Public License version 2 or later 
// <http://www.gnu.org/copyleft/gpl.html>
//
// $Id: HtCodec.cc,v 1.2 2002/11/14 16:59:05 angusgb Exp $
//


#ifdef HAVE_CONFIG_H
#include "htconfig.h"
#endif /* HAVE_CONFIG_H */

#include "HtCodec.h"

HtCodec::HtCodec()
{ }

HtCodec::~HtCodec()
{ }

// End of HtCodec.cc
